==> huaweicloudsdkcbr-3.1.67-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/agent_remove_path_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgentRemovePathReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'remove_path': 'list[str]'
    }

    attribute_map = {
        'remove_path': 'remove_path'
    }

    def __init__(self, remove_path=None):
        """AgentRemovePathReq

        The model defined in huaweicloud sdk

        :param remove_path: 移除备份路径详情 
        :type remove_path: list[str]
        """
        
        

        self._remove_path = None
        self.discriminator = None

        self.remove_path = remove_path

    @property
    def remove_path(self):
        """Gets the remove_path of this AgentRemovePathReq.

        移除备份路径详情 

        :return: The remove_path of this AgentRemovePathReq.
        :rtype: list[str]
        """
        return self._remove_path

    @remove_path.setter
    def remove_path(self, remove_path):
        """Sets the remove_path of this AgentRemovePathReq.

        移除备份路径详情 

        :param remove_path: The remove_path of this AgentRemovePathReq.
        :type remove_path: list[str]
        """
        self._remove_path = remove_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentRemovePathReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.1.157-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/agent_remove_path_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgentRemovePathReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'remove_path': 'list[str]'
    }

    attribute_map = {
        'remove_path': 'remove_path'
    }

    def __init__(self, remove_path=None):
        r"""AgentRemovePathReq

        The model defined in huaweicloud sdk

        :param remove_path: 移除备份路径详情 
        :type remove_path: list[str]
        """
        
        

        self._remove_path = None
        self.discriminator = None

        self.remove_path = remove_path

    @property
    def remove_path(self):
        r"""Gets the remove_path of this AgentRemovePathReq.

        移除备份路径详情 

        :return: The remove_path of this AgentRemovePathReq.
        :rtype: list[str]
        """
        return self._remove_path

    @remove_path.setter
    def remove_path(self, remove_path):
        r"""Sets the remove_path of this AgentRemovePathReq.

        移除备份路径详情 

        :param remove_path: The remove_path of this AgentRemovePathReq.
        :type remove_path: list[str]
        """
        self._remove_path = remove_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentRemovePathReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
